@@ -84,7 +84,7 @@ class AccessAnalyzerClient:
     def create_archive_rule(
         self,
         analyzerName: str,
-        filter: Dict[str, CriterionTypeDef],
+        filter: Dict[str, "CriterionTypeDef"],
         ruleName: str,
         clientToken: str = None,
     ) -> None:
@@ -175,7 +175,7 @@ class AccessAnalyzerClient:
     def list_findings(
         self,
         analyzerArn: str,
-        filter: Dict[str, CriterionTypeDef] = None,
+        filter: Dict[str, "CriterionTypeDef"] = None,
         maxResults: int = None,
         nextToken: str = None,
         sort: SortCriteriaTypeDef = None,
@@ -207,7 +207,7 @@ class AccessAnalyzerClient:
     def update_archive_rule(
         self,
         analyzerName: str,
-        filter: Dict[str, CriterionTypeDef],
+        filter: Dict[str, "CriterionTypeDef"],
         ruleName: str,
         clientToken: str = None,
     ) -> None:
