@@ -105,7 +105,7 @@ class ListFindingsPaginator(Boto3Paginator):
     def paginate(
         self,
         analyzerArn: str,
-        filter: Dict[str, CriterionTypeDef] = None,
+        filter: Dict[str, "CriterionTypeDef"] = None,
         sort: SortCriteriaTypeDef = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListFindingsResponseTypeDef]:
