@@ -3,9 +3,9 @@ Main interface for accessanalyzer service type definitions.
 
 Usage::
 
-    from mypy_boto3.accessanalyzer.type_defs import CreateAnalyzerResponseTypeDef
+    from mypy_boto3.accessanalyzer.type_defs import AnalyzedResourceSummaryTypeDef
 
-    data: CreateAnalyzerResponseTypeDef = {...}
+    data: AnalyzedResourceSummaryTypeDef = {...}
 """
 from datetime import datetime
 import sys
@@ -22,39 +22,45 @@ else:
 
 
 __all__ = (
-    "CreateAnalyzerResponseTypeDef",
-    "CriterionTypeDef",
+    "AnalyzedResourceSummaryTypeDef",
     "AnalyzedResourceTypeDef",
-    "GetAnalyzedResourceResponseTypeDef",
-    "StatusReasonTypeDef",
     "AnalyzerSummaryTypeDef",
-    "GetAnalyzerResponseTypeDef",
     "ArchiveRuleSummaryTypeDef",
-    "GetArchiveRuleResponseTypeDef",
+    "CriterionTypeDef",
     "FindingSourceDetailTypeDef",
     "FindingSourceTypeDef",
+    "FindingSummaryTypeDef",
     "FindingTypeDef",
+    "StatusReasonTypeDef",
+    "CreateAnalyzerResponseTypeDef",
+    "GetAnalyzedResourceResponseTypeDef",
+    "GetAnalyzerResponseTypeDef",
+    "GetArchiveRuleResponseTypeDef",
     "GetFindingResponseTypeDef",
     "InlineArchiveRuleTypeDef",
-    "AnalyzedResourceSummaryTypeDef",
     "ListAnalyzedResourcesResponseTypeDef",
     "ListAnalyzersResponseTypeDef",
     "ListArchiveRulesResponseTypeDef",
-    "FindingSummaryTypeDef",
     "ListFindingsResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "PaginatorConfigTypeDef",
     "SortCriteriaTypeDef",
 )
 
-CreateAnalyzerResponseTypeDef = TypedDict(
-    "CreateAnalyzerResponseTypeDef", {"arn": str}, total=False
-)
-
-CriterionTypeDef = TypedDict(
-    "CriterionTypeDef",
-    {"contains": List[str], "eq": List[str], "exists": bool, "neq": List[str]},
-    total=False,
+AnalyzedResourceSummaryTypeDef = TypedDict(
+    "AnalyzedResourceSummaryTypeDef",
+    {
+        "resourceArn": str,
+        "resourceOwnerAccount": str,
+        "resourceType": Literal[
+            "AWS::IAM::Role",
+            "AWS::KMS::Key",
+            "AWS::Lambda::Function",
+            "AWS::Lambda::LayerVersion",
+            "AWS::S3::Bucket",
+            "AWS::SQS::Queue",
+        ],
+    },
 )
 
 _RequiredAnalyzedResourceTypeDef = TypedDict(
@@ -92,22 +98,6 @@ class AnalyzedResourceTypeDef(_RequiredAnalyzedResourceTypeDef, _OptionalAnalyze
     pass
 
 
-GetAnalyzedResourceResponseTypeDef = TypedDict(
-    "GetAnalyzedResourceResponseTypeDef", {"resource": AnalyzedResourceTypeDef}, total=False
-)
-
-StatusReasonTypeDef = TypedDict(
-    "StatusReasonTypeDef",
-    {
-        "code": Literal[
-            "AWS_SERVICE_ACCESS_DISABLED",
-            "DELEGATED_ADMINISTRATOR_DEREGISTERED",
-            "ORGANIZATION_DELETED",
-            "SERVICE_LINKED_ROLE_CREATION_FAILED",
-        ]
-    },
-)
-
 _RequiredAnalyzerSummaryTypeDef = TypedDict(
     "_RequiredAnalyzerSummaryTypeDef",
     {
@@ -123,7 +113,7 @@ _OptionalAnalyzerSummaryTypeDef = TypedDict(
     {
         "lastResourceAnalyzed": str,
         "lastResourceAnalyzedAt": datetime,
-        "statusReason": StatusReasonTypeDef,
+        "statusReason": "StatusReasonTypeDef",
         "tags": Dict[str, str],
     },
     total=False,
@@ -134,22 +124,20 @@ class AnalyzerSummaryTypeDef(_RequiredAnalyzerSummaryTypeDef, _OptionalAnalyzerS
     pass
 
 
-GetAnalyzerResponseTypeDef = TypedDict(
-    "GetAnalyzerResponseTypeDef", {"analyzer": AnalyzerSummaryTypeDef}
-)
-
 ArchiveRuleSummaryTypeDef = TypedDict(
     "ArchiveRuleSummaryTypeDef",
     {
         "createdAt": datetime,
-        "filter": Dict[str, CriterionTypeDef],
+        "filter": Dict[str, "CriterionTypeDef"],
         "ruleName": str,
         "updatedAt": datetime,
     },
 )
 
-GetArchiveRuleResponseTypeDef = TypedDict(
-    "GetArchiveRuleResponseTypeDef", {"archiveRule": ArchiveRuleSummaryTypeDef}
+CriterionTypeDef = TypedDict(
+    "CriterionTypeDef",
+    {"contains": List[str], "eq": List[str], "exists": bool, "neq": List[str]},
+    total=False,
 )
 
 FindingSourceDetailTypeDef = TypedDict(
@@ -160,7 +148,7 @@ _RequiredFindingSourceTypeDef = TypedDict(
     "_RequiredFindingSourceTypeDef", {"type": Literal["BUCKET_ACL", "POLICY", "S3_ACCESS_POINT"]}
 )
 _OptionalFindingSourceTypeDef = TypedDict(
-    "_OptionalFindingSourceTypeDef", {"detail": FindingSourceDetailTypeDef}, total=False
+    "_OptionalFindingSourceTypeDef", {"detail": "FindingSourceDetailTypeDef"}, total=False
 )
 
 
@@ -168,111 +156,6 @@ class FindingSourceTypeDef(_RequiredFindingSourceTypeDef, _OptionalFindingSource
     pass
 
 
-_RequiredFindingTypeDef = TypedDict(
-    "_RequiredFindingTypeDef",
-    {
-        "analyzedAt": datetime,
-        "condition": Dict[str, str],
-        "createdAt": datetime,
-        "id": str,
-        "resourceOwnerAccount": str,
-        "resourceType": Literal[
-            "AWS::IAM::Role",
-            "AWS::KMS::Key",
-            "AWS::Lambda::Function",
-            "AWS::Lambda::LayerVersion",
-            "AWS::S3::Bucket",
-            "AWS::SQS::Queue",
-        ],
-        "status": Literal["ACTIVE", "ARCHIVED", "RESOLVED"],
-        "updatedAt": datetime,
-    },
-)
-_OptionalFindingTypeDef = TypedDict(
-    "_OptionalFindingTypeDef",
-    {
-        "action": List[str],
-        "error": str,
-        "isPublic": bool,
-        "principal": Dict[str, str],
-        "resource": str,
-        "sources": List[FindingSourceTypeDef],
-    },
-    total=False,
-)
-
-
-class FindingTypeDef(_RequiredFindingTypeDef, _OptionalFindingTypeDef):
-    pass
-
-
-GetFindingResponseTypeDef = TypedDict(
-    "GetFindingResponseTypeDef", {"finding": FindingTypeDef}, total=False
-)
-
-InlineArchiveRuleTypeDef = TypedDict(
-    "InlineArchiveRuleTypeDef", {"filter": Dict[str, CriterionTypeDef], "ruleName": str}
-)
-
-AnalyzedResourceSummaryTypeDef = TypedDict(
-    "AnalyzedResourceSummaryTypeDef",
-    {
-        "resourceArn": str,
-        "resourceOwnerAccount": str,
-        "resourceType": Literal[
-            "AWS::IAM::Role",
-            "AWS::KMS::Key",
-            "AWS::Lambda::Function",
-            "AWS::Lambda::LayerVersion",
-            "AWS::S3::Bucket",
-            "AWS::SQS::Queue",
-        ],
-    },
-)
-
-_RequiredListAnalyzedResourcesResponseTypeDef = TypedDict(
-    "_RequiredListAnalyzedResourcesResponseTypeDef",
-    {"analyzedResources": List[AnalyzedResourceSummaryTypeDef]},
-)
-_OptionalListAnalyzedResourcesResponseTypeDef = TypedDict(
-    "_OptionalListAnalyzedResourcesResponseTypeDef", {"nextToken": str}, total=False
-)
-
-
-class ListAnalyzedResourcesResponseTypeDef(
-    _RequiredListAnalyzedResourcesResponseTypeDef, _OptionalListAnalyzedResourcesResponseTypeDef
-):
-    pass
-
-
-_RequiredListAnalyzersResponseTypeDef = TypedDict(
-    "_RequiredListAnalyzersResponseTypeDef", {"analyzers": List[AnalyzerSummaryTypeDef]}
-)
-_OptionalListAnalyzersResponseTypeDef = TypedDict(
-    "_OptionalListAnalyzersResponseTypeDef", {"nextToken": str}, total=False
-)
-
-
-class ListAnalyzersResponseTypeDef(
-    _RequiredListAnalyzersResponseTypeDef, _OptionalListAnalyzersResponseTypeDef
-):
-    pass
-
-
-_RequiredListArchiveRulesResponseTypeDef = TypedDict(
-    "_RequiredListArchiveRulesResponseTypeDef", {"archiveRules": List[ArchiveRuleSummaryTypeDef]}
-)
-_OptionalListArchiveRulesResponseTypeDef = TypedDict(
-    "_OptionalListArchiveRulesResponseTypeDef", {"nextToken": str}, total=False
-)
-
-
-class ListArchiveRulesResponseTypeDef(
-    _RequiredListArchiveRulesResponseTypeDef, _OptionalListArchiveRulesResponseTypeDef
-):
-    pass
-
-
 _RequiredFindingSummaryTypeDef = TypedDict(
     "_RequiredFindingSummaryTypeDef",
     {
@@ -301,7 +184,7 @@ _OptionalFindingSummaryTypeDef = TypedDict(
         "isPublic": bool,
         "principal": Dict[str, str],
         "resource": str,
-        "sources": List[FindingSourceTypeDef],
+        "sources": List["FindingSourceTypeDef"],
     },
     total=False,
 )
@@ -311,8 +194,125 @@ class FindingSummaryTypeDef(_RequiredFindingSummaryTypeDef, _OptionalFindingSumm
     pass
 
 
+_RequiredFindingTypeDef = TypedDict(
+    "_RequiredFindingTypeDef",
+    {
+        "analyzedAt": datetime,
+        "condition": Dict[str, str],
+        "createdAt": datetime,
+        "id": str,
+        "resourceOwnerAccount": str,
+        "resourceType": Literal[
+            "AWS::IAM::Role",
+            "AWS::KMS::Key",
+            "AWS::Lambda::Function",
+            "AWS::Lambda::LayerVersion",
+            "AWS::S3::Bucket",
+            "AWS::SQS::Queue",
+        ],
+        "status": Literal["ACTIVE", "ARCHIVED", "RESOLVED"],
+        "updatedAt": datetime,
+    },
+)
+_OptionalFindingTypeDef = TypedDict(
+    "_OptionalFindingTypeDef",
+    {
+        "action": List[str],
+        "error": str,
+        "isPublic": bool,
+        "principal": Dict[str, str],
+        "resource": str,
+        "sources": List["FindingSourceTypeDef"],
+    },
+    total=False,
+)
+
+
+class FindingTypeDef(_RequiredFindingTypeDef, _OptionalFindingTypeDef):
+    pass
+
+
+StatusReasonTypeDef = TypedDict(
+    "StatusReasonTypeDef",
+    {
+        "code": Literal[
+            "AWS_SERVICE_ACCESS_DISABLED",
+            "DELEGATED_ADMINISTRATOR_DEREGISTERED",
+            "ORGANIZATION_DELETED",
+            "SERVICE_LINKED_ROLE_CREATION_FAILED",
+        ]
+    },
+)
+
+CreateAnalyzerResponseTypeDef = TypedDict(
+    "CreateAnalyzerResponseTypeDef", {"arn": str}, total=False
+)
+
+GetAnalyzedResourceResponseTypeDef = TypedDict(
+    "GetAnalyzedResourceResponseTypeDef", {"resource": "AnalyzedResourceTypeDef"}, total=False
+)
+
+GetAnalyzerResponseTypeDef = TypedDict(
+    "GetAnalyzerResponseTypeDef", {"analyzer": "AnalyzerSummaryTypeDef"}
+)
+
+GetArchiveRuleResponseTypeDef = TypedDict(
+    "GetArchiveRuleResponseTypeDef", {"archiveRule": "ArchiveRuleSummaryTypeDef"}
+)
+
+GetFindingResponseTypeDef = TypedDict(
+    "GetFindingResponseTypeDef", {"finding": "FindingTypeDef"}, total=False
+)
+
+InlineArchiveRuleTypeDef = TypedDict(
+    "InlineArchiveRuleTypeDef", {"filter": Dict[str, "CriterionTypeDef"], "ruleName": str}
+)
+
+_RequiredListAnalyzedResourcesResponseTypeDef = TypedDict(
+    "_RequiredListAnalyzedResourcesResponseTypeDef",
+    {"analyzedResources": List["AnalyzedResourceSummaryTypeDef"]},
+)
+_OptionalListAnalyzedResourcesResponseTypeDef = TypedDict(
+    "_OptionalListAnalyzedResourcesResponseTypeDef", {"nextToken": str}, total=False
+)
+
+
+class ListAnalyzedResourcesResponseTypeDef(
+    _RequiredListAnalyzedResourcesResponseTypeDef, _OptionalListAnalyzedResourcesResponseTypeDef
+):
+    pass
+
+
+_RequiredListAnalyzersResponseTypeDef = TypedDict(
+    "_RequiredListAnalyzersResponseTypeDef", {"analyzers": List["AnalyzerSummaryTypeDef"]}
+)
+_OptionalListAnalyzersResponseTypeDef = TypedDict(
+    "_OptionalListAnalyzersResponseTypeDef", {"nextToken": str}, total=False
+)
+
+
+class ListAnalyzersResponseTypeDef(
+    _RequiredListAnalyzersResponseTypeDef, _OptionalListAnalyzersResponseTypeDef
+):
+    pass
+
+
+_RequiredListArchiveRulesResponseTypeDef = TypedDict(
+    "_RequiredListArchiveRulesResponseTypeDef", {"archiveRules": List["ArchiveRuleSummaryTypeDef"]}
+)
+_OptionalListArchiveRulesResponseTypeDef = TypedDict(
+    "_OptionalListArchiveRulesResponseTypeDef", {"nextToken": str}, total=False
+)
+
+
+class ListArchiveRulesResponseTypeDef(
+    _RequiredListArchiveRulesResponseTypeDef, _OptionalListArchiveRulesResponseTypeDef
+):
+    pass
+
+
 _RequiredListFindingsResponseTypeDef = TypedDict(
-    "_RequiredListFindingsResponseTypeDef", {"findings": List[FindingSummaryTypeDef]}
+    "_RequiredListFindingsResponseTypeDef", {"findings": List["FindingSummaryTypeDef"]}
 )
 _OptionalListFindingsResponseTypeDef = TypedDict(
     "_OptionalListFindingsResponseTypeDef", {"nextToken": str}, total=False
